"""
    domonic.webapi.clipboard
    ====================================

"""

# class ClipboardData():
    # clipboardData Returns an object containing the data affected by the clipboard operation
    # def __init__():
        # pass
